==> virtualbox-sdk-6.0.14-4-x86_64.pkg.tar.xz: org/virtualbox_6_0/jaxws/IMachineSetVMProcessPriority.java <==

package org.virtualbox_6_0.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="_this" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="VMProcessPriority" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_this",
    "vmProcessPriority"
})
@XmlRootElement(name = "IMachine_setVMProcessPriority")
public class IMachineSetVMProcessPriority {

    @XmlElement(required = true)
    protected String _this;
    @XmlElement(name = "VMProcessPriority", required = true)
    protected String vmProcessPriority;

    /**
     * Gets the value of the this property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getThis() {
        return _this;
    }

    /**
     * Sets the value of the this property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setThis(String value) {
        this._this = value;
    }

    /**
     * Gets the value of the vmProcessPriority property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVMProcessPriority() {
        return vmProcessPriority;
    }

    /**
     * Sets the value of the vmProcessPriority property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVMProcessPriority(String value) {
        this.vmProcessPriority = value;
    }

}

==> virtualbox-sdk-6.1.0-1-x86_64.pkg.tar.xz: org/virtualbox_6_1/jaxws/IMachineSetVMProcessPriority.java <==

package org.virtualbox_6_1.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="_this" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="VMProcessPriority" type="{http://www.virtualbox.org/}VMProcPriority"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_this",
    "vmProcessPriority"
})
@XmlRootElement(name = "IMachine_setVMProcessPriority")
public class IMachineSetVMProcessPriority {

    @XmlElement(required = true)
    protected String _this;
    @XmlElement(name = "VMProcessPriority", required = true)
    protected VMProcPriority vmProcessPriority;

    /**
     * Gets the value of the this property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getThis() {
        return _this;
    }

    /**
     * Sets the value of the this property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setThis(String value) {
        this._this = value;
    }

    /**
     * Gets the value of the vmProcessPriority property.
     * 
     * @return
     *     possible object is
     *     {@link VMProcPriority }
     *     
     */
    public VMProcPriority getVMProcessPriority() {
        return vmProcessPriority;
    }

    /**
     * Sets the value of the vmProcessPriority property.
     * 
     * @param value
     *     allowed object is
     *     {@link VMProcPriority }
     *     
     */
    public void setVMProcessPriority(VMProcPriority value) {
        this.vmProcessPriority = value;
    }

}
